@@ -152,6 +152,10 @@ def handle_artifacts(source_file_path, target_dir, source_sub_folder=None):
                 z.extractall(temp_target_dir)
                 # move all files in temp_target_dir/source_sub_dir to target_dir
                 for file in os.listdir(os.path.join(temp_target_dir, source_sub_folder)):
+                    # if filename is "wait_for_db_ready.sh", chmod +x first
+                    if file == "wait_for_db_ready.sh":
+                        os.chmod(os.path.join(temp_target_dir, source_sub_folder, file), 0o777)
+
                     os.rename(os.path.join(temp_target_dir, source_sub_folder, file), os.path.join(target_dir, file))
                 # remove temp_target_dir all
                 shutil.rmtree(temp_target_dir)
